==> qmmp-0.10.10.tar.bz2: qmmp-0.10.10/src/plugins/CommandLineOptions/IncDecVolumeOption/incdecvolumeoption.cpp <==
/***************************************************************************
 *   Copyright (C) 2008-2016 by Ilya Kotov                                 *
 *   forkotov02@hotmail.ru                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/

#include <QtPlugin>
#include <QTranslator>
#include <QLocale>
#include <qmmp/soundcore.h>

#include "incdecvolumeoption.h"

bool IncDecVolumeCommandLineOption::identify(const QString & str) const
{
    if (
        str == QString("--volume-inc") ||
        str == QString("--volume-dec")
    )
    {
        return true;
    }

    return false;
}

const QString IncDecVolumeCommandLineOption::helpString() const
{
    return  QString(
                "--volume-inc             " + tr("Increase volume by 5 steps")+"\n"
                "--volume-dec             " + tr("Decrease volume by 5 steps")+"\n"
            );
}

QString IncDecVolumeCommandLineOption::executeCommand(const QString& opt_str, const QStringList &args)
{
    Q_UNUSED(args);

    if (opt_str == "--volume-inc")
        SoundCore::instance()->volumeUp();
    else if (opt_str == "--volume-dec")
        SoundCore::instance()->volumeDown();

    return QString();
}

const QString IncDecVolumeCommandLineOption::name() const
{
    return "IncDecVolumeCommandLineOption";
}

QTranslator *IncDecVolumeCommandLineOption::createTranslator(QObject *parent)
{
    QTranslator *translator = new QTranslator(parent);
    QString locale = Qmmp::systemLanguageID();
    translator->load(QString(":/incdecvolume_plugin_") + locale);
    return translator;
}

Q_EXPORT_PLUGIN2(incdecvolumeoption, IncDecVolumeCommandLineOption)

==> qmmp-0.12.4.tar.bz2: qmmp-0.12.4/src/plugins/CommandLineOptions/IncDecVolumeOption/incdecvolumeoption.cpp <==
/***************************************************************************
 *   Copyright (C) 2008-2019 by Ilya Kotov                                 *
 *   forkotov02@ya.ru                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/

#include <QtPlugin>
#include <QLocale>
#include <QPair>
#include <qmmp/soundcore.h>
#include "incdecvolumeoption.h"

void IncDecVolumeCommandLineOption::registerOprions()
{
    registerOption(VOLUME_UP, "--volume-inc", tr("Increase volume by 5 steps"));
    registerOption(VOLUME_DOWN, "--volume-dec", tr("Decrease volume by 5 steps"));
}

QString IncDecVolumeCommandLineOption::shortName() const
{
    return "IncDecVolumeCommandLineOption";
}

QString IncDecVolumeCommandLineOption::translation() const
{
    return QLatin1String(":/incdecvolume_plugin_");
}

QString IncDecVolumeCommandLineOption::executeCommand(int id, const QStringList &args)
{
    Q_UNUSED(args);

    switch (id)
    {
    case VOLUME_UP:
        SoundCore::instance()->volumeUp();
        break;
    case VOLUME_DOWN:
        SoundCore::instance()->volumeDown();
        break;
    default:
        break;
    }

    return QString();
}

Q_EXPORT_PLUGIN2(incdecvolumeoption, IncDecVolumeCommandLineOption)
